/*
 * *************************************************
 * Copyright (c) 2019 QMTH. All Rights Reserved.
 * Created by Deason on 2019-05-23 11:39:38.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.questions.service.bean.paper;

import cn.com.qmth.examcloud.core.questions.base.question.enums.QuesStructType;
import cn.com.qmth.examcloud.core.questions.dao.entity.Question;
import cn.com.qmth.examcloud.core.questions.service.bean.dto.PaperDetailExp;
import cn.com.qmth.examcloud.core.questions.service.bean.dto.PaperDetailUnitExp;
import org.apache.commons.collections.CollectionUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 试卷导出内容处理
 *
 * @author: fengdesheng
 * @since: 2019/5/23
 */
public class ExportPaperHandler {

    /**
     * 对相同类型的大题分组，生成不同的集合放入小题，再对小题排序
     */
    public static void sortPaperDetailUnits(List<PaperDetailExp> details) {
        int index = 0;
        Map<Long, List<PaperDetailUnitExp>> map = new HashMap<>();

        //循环所有大题,将同类型的小题放到同一个集合下面
        for (PaperDetailExp detail : details) {
            //单选，多选，判断放在同一集合下排序
            List<PaperDetailUnitExp> units;
            Long sortNumber = detail.getSortNumber();
            if (sortNumber < 4L) {
                units = map.get(sortNumber);
                if (units == null) {
                    units = new ArrayList<>();
                }
                units.addAll(detail.getPaperDetailUnits());
                map.put(sortNumber, units);
            } else {
                units = new ArrayList<>();
                units.addAll(detail.getPaperDetailUnits());
                map.put(sortNumber + index, units);
                index++;
            }
        }

        //循环所有小题，给小题排序
        for (Long sortNumber : map.keySet()) {
            List<PaperDetailUnitExp> utils = map.get(sortNumber);
            if (CollectionUtils.isEmpty(utils)) {
                continue;
            }

            int number = 1;//小题号
            int nestedNumber = 1;//套题号
            for (int i = 0; i < utils.size(); i++) {
                PaperDetailUnitExp unit = utils.get(i);
                if (unit.getQuestionType() == QuesStructType.NESTED_ANSWER_QUESTION) {
                    unit.setNumber(nestedNumber);
                    List<Question> subQuestions = unit.getQuestion().getSubQuestions();
                    for (int j = 0; j < subQuestions.size(); j++) {
                        subQuestions.get(j).setNumber(number + j);
                    }
                    number += subQuestions.size();
                    nestedNumber++;
                } else {
                    unit.setNumber(number);
                    number++;
                }
            }
        }
    }

}